[jboss-svn-commits] JBL Code SVN: r9598 - in labs/jbosslabs/trunk/portal-extensions/forge-common/src: java/org/jboss/forge/common/projects/project/rw and 1 other directories.

jboss-svn-commits at lists.jboss.org jboss-svn-commits at lists.jboss.org
Mon Feb 19 09:39:14 EST 2007


Author: unibrew
Date: 2007-02-19 09:39:14 -0500 (Mon, 19 Feb 2007)
New Revision: 9598

Modified:
   labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/Project.java
   labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/rw/ProjectRW.java
   labs/jbosslabs/trunk/portal-extensions/forge-common/src/web/WEB-INF/project.xsd
Log:
[JBLAB-841] Small spelling correction update.

Modified: labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/Project.java
===================================================================
--- labs/jbosslabs/trunk/portal-extensions/forge-common/src/web/WEB-INF/project.xsd	2007-02-19 14:32:00 UTC (rev 9597)
+++ labs/jbosslabs/trunk/portal-extensions/forge-common/src/web/WEB-INF/project.xsd	2007-02-19 14:39:14 UTC (rev 9598)
@@ -71,7 +71,7 @@
             <xs:element name="jems" minOccurs="0" maxOccurs="unbounded" type="xs:string" />
             <xs:element name="repo-type" minOccurs="0" maxOccurs="1" type="RepoType" />
             <xs:element name="anon-repo" minOccurs="0" maxOccurs="1" type="xs:string" />
-            <xs:element name="commmiter-repo" minOccurs="0" maxOccurs="1" type="xs:string" />
+            <xs:element name="commiter-repo" minOccurs="0" maxOccurs="1" type="xs:string" />
             <xs:element name="repo-monitor" minOccurs="0" maxOccurs="1" type="repo-monitor" />
             <xs:element name="issue-tracker" minOccurs="0" maxOccurs="1" type="issue-tracker" />      
             <xs:element name="build-results" type="build-result" minOccurs="0" maxOccurs="unbounded" />




More information about the jboss-svn-commits mailing list
--- labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/Project.java	2007-02-19 14:32:00 UTC (rev 9597)
+++ labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/Project.java	2007-02-19 14:39:14 UTC (rev 9598)
@@ -22,9 +22,8 @@
 
 package org.jboss.forge.common.projects.project;
 
-import java.io.Serializable;
+import java.util.ArrayList;
 import java.util.List;
-import java.util.Vector;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
@@ -54,7 +53,7 @@
     "jems",
     "repoType",
     "anonRepo",
-    "commmiterRepo",
+    "commiterRepo",
     "repoMonitor",
     "issueTracker",
     "buildResults",
@@ -69,11 +68,8 @@
     "polls"
 })
 @XmlRootElement(name = "project")
-public class Project
-    implements Serializable
-{
+public class Project {
 
-    private final static long serialVersionUID = 1L;
     @XmlElement(required = true)
     protected String id;
     @XmlElement(required = true)
@@ -84,19 +80,19 @@
     protected String description;
     protected String info;
     protected Developers developers;
-    protected List<String> jems = new Vector<String>();
+    protected List<String> jems;
     @XmlElement(name = "repo-type")
     protected RepoType repoType;
     @XmlElement(name = "anon-repo")
     protected String anonRepo;
-    @XmlElement(name = "commmiter-repo")
-    protected String commmiterRepo;
+    @XmlElement(name = "commiter-repo")
+    protected String commiterRepo;
     @XmlElement(name = "repo-monitor")
     protected RepoMonitor repoMonitor;
     @XmlElement(name = "issue-tracker")
     protected IssueTracker issueTracker;
     @XmlElement(name = "build-results")
-    protected List<BuildResult> buildResults = new Vector<BuildResult>();
+    protected List<BuildResult> buildResults;
     protected String support;
     protected String training;
     @XmlElement(name = "packaged-for-download", defaultValue = "false")
@@ -105,7 +101,7 @@
     protected String userForum;
     @XmlElement(name = "dev-forum")
     protected String devForum;
-    protected List<Documentation> documentation = new Vector<Documentation>();
+    protected List<Documentation> documentation;
     @XmlElement(required = true)
     protected Pages pages;
     protected Downloads downloads;
@@ -303,7 +299,7 @@
      */
     public List<String> getJems() {
         if (jems == null) {
-            jems = new Vector<String>();
+            jems = new ArrayList<String>();
         }
         return this.jems;
     }
@@ -357,27 +353,27 @@
     }
 
     /**
      * Gets the value of the commmiterRepo property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public String getCommmiterRepo() {
-        return commmiterRepo;
+    public String getCommiterRepo() {
+        return commiterRepo;
     }
 
     /**
      * Sets the value of the commmiterRepo property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public void setCommmiterRepo(String value) {
-        this.commmiterRepo = value;
+    public void setCommiterRepo(String value) {
+        this.commiterRepo = value;
     }
 
     /**
@@ -452,7 +448,7 @@
      */
     public List<BuildResult> getBuildResults() {
         if (buildResults == null) {
-            buildResults = new Vector<BuildResult>();
+            buildResults = new ArrayList<BuildResult>();
         }
         return this.buildResults;
     }
@@ -593,7 +589,7 @@
      */
     public List<Documentation> getDocumentation() {
         if (documentation == null) {
-            documentation = new Vector<Documentation>();
+            documentation = new ArrayList<Documentation>();
         }
         return this.documentation;
     }
@@ -357,27 +353,27 @@
 
     /**
-     * Gets the value of the commmiterRepo property.
+     * Gets the value of the commiterRepo property.
      * 
      * @return
@@ -357,27 +353,27 @@
 
     /**
-     * Sets the value of the commmiterRepo property.
+     * Sets the value of the commiterRepo property.
      * 
      * @param value

Modified: labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/rw/ProjectRW.java
===================================================================
--- labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/rw/ProjectRW.java	2007-02-19 14:32:00 UTC (rev 9597)
+++ labs/jbosslabs/trunk/portal-extensions/forge-common/src/java/org/jboss/forge/common/projects/project/rw/ProjectRW.java	2007-02-19 14:39:14 UTC (rev 9598)
@@ -54,7 +54,7 @@
     "jems",
     "repoType",
     "anonRepo",
-    "commmiterRepo",
+    "commiterRepo",
     "repoMonitor",
     "issueTracker",
     "buildResults",
@@ -89,8 +89,8 @@
     protected RepoTypeRW repoType;
     @XmlElement(name = "anon-repo")
     protected String anonRepo;
-    @XmlElement(name = "commmiter-repo")
-    protected String commmiterRepo;
+    @XmlElement(name = "commiter-repo")
+    protected String commiterRepo;
     @XmlElement(name = "repo-monitor")
     protected RepoMonitorRW repoMonitor;
     @XmlElement(name = "issue-tracker")
@@ -119,7 +119,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getId() {
+    public String getId() {
         return id;
     }
 
@@ -131,7 +131,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setId(String value) {
+    public void setId(String value) {
         this.id = value;
     }
 
@@ -143,7 +143,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getName() {
+    public String getName() {
         return name;
     }
 
@@ -155,7 +155,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setName(String value) {
+    public void setName(String value) {
         this.name = value;
     }
 
@@ -167,7 +167,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getCompanyName() {
+    public String getCompanyName() {
         return companyName;
     }
 
@@ -179,7 +179,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setCompanyName(String value) {
+    public void setCompanyName(String value) {
         this.companyName = value;
     }
 
@@ -191,7 +191,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getLogo() {
+    public String getLogo() {
         return logo;
     }
 
@@ -203,7 +203,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setLogo(String value) {
+    public void setLogo(String value) {
         this.logo = value;
     }
 
@@ -215,7 +215,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getDescription() {
+    public String getDescription() {
         return description;
     }
 
@@ -227,7 +227,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setDescription(String value) {
+    public void setDescription(String value) {
         this.description = value;
     }
 
@@ -239,7 +239,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getInfo() {
+    public String getInfo() {
         return info;
     }
 
@@ -251,7 +251,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setInfo(String value) {
+    public void setInfo(String value) {
         this.info = value;
     }
 
@@ -263,7 +263,7 @@
      *     {@link DevelopersRW }
      *     
      */
-    public synchronized DevelopersRW getDevelopers() {
+    public DevelopersRW getDevelopers() {
         return developers;
     }
 
@@ -275,7 +275,7 @@
      *     {@link DevelopersRW }
      *     
      */
-    public synchronized void setDevelopers(DevelopersRW value) {
+    public void setDevelopers(DevelopersRW value) {
         this.developers = value;
     }
 
@@ -301,7 +301,7 @@
      * 
      * 
      */
-    public synchronized List<String> getJems() {
+    public List<String> getJems() {
         if (jems == null) {
             jems = new CopyOnWriteArrayList<String>();
         }
@@ -316,7 +316,7 @@
      *     {@link RepoTypeRW }
      *     
      */
-    public synchronized RepoTypeRW getRepoType() {
+    public RepoTypeRW getRepoType() {
         return repoType;
     }
 
@@ -328,7 +328,7 @@
      *     {@link RepoTypeRW }
      *     
      */
-    public synchronized void setRepoType(RepoTypeRW value) {
+    public void setRepoType(RepoTypeRW value) {
         this.repoType = value;
     }
 
@@ -340,7 +340,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getAnonRepo() {
+    public String getAnonRepo() {
         return anonRepo;
     }
 
@@ -352,32 +352,32 @@
      *     {@link String }
      *     
      */
-    public synchronized void setAnonRepo(String value) {
+    public void setAnonRepo(String value) {
         this.anonRepo = value;
     }
 
     /**
      * Gets the value of the commmiterRepo property.
      * 
      * @return
      *     possible object is
      *     {@link String }
      *     
      */
-    public synchronized String getCommmiterRepo() {
-        return commmiterRepo;
+    public String getCommiterRepo() {
+        return commiterRepo;
     }
 
     /**
      * Sets the value of the commmiterRepo property.
      * 
      * @param value
      *     allowed object is
      *     {@link String }
      *     
      */
-    public synchronized void setCommmiterRepo(String value) {
-        this.commmiterRepo = value;
+    public void setCommiterRepo(String value) {
+        this.commiterRepo = value;
     }
 
     /**
@@ -388,7 +388,7 @@
      *     {@link RepoMonitorRW }
      *     
      */
-    public synchronized RepoMonitorRW getRepoMonitor() {
+    public RepoMonitorRW getRepoMonitor() {
         return repoMonitor;
     }
 
@@ -400,7 +400,7 @@
      *     {@link RepoMonitorRW }
      *     
      */
-    public synchronized void setRepoMonitor(RepoMonitorRW value) {
+    public void setRepoMonitor(RepoMonitorRW value) {
         this.repoMonitor = value;
     }
 
@@ -412,7 +412,7 @@
      *     {@link IssueTrackerRW }
      *     
      */
-    public synchronized IssueTrackerRW getIssueTracker() {
+    public IssueTrackerRW getIssueTracker() {
         return issueTracker;
     }
 
@@ -424,7 +424,7 @@
      *     {@link IssueTrackerRW }
      *     
      */
-    public synchronized void setIssueTracker(IssueTrackerRW value) {
+    public void setIssueTracker(IssueTrackerRW value) {
         this.issueTracker = value;
     }
 
@@ -450,7 +450,7 @@
      * 
      * 
      */
-    public synchronized List<BuildResultRW> getBuildResults() {
+    public List<BuildResultRW> getBuildResults() {
         if (buildResults == null) {
             buildResults = new CopyOnWriteArrayList<BuildResultRW>();
         }
@@ -465,7 +465,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getSupport() {
+    public String getSupport() {
         return support;
     }
 
@@ -477,7 +477,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setSupport(String value) {
+    public void setSupport(String value) {
         this.support = value;
     }
 
@@ -489,7 +489,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getTraining() {
+    public String getTraining() {
         return training;
     }
 
@@ -501,7 +501,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setTraining(String value) {
+    public void setTraining(String value) {
         this.training = value;
     }
 
@@ -509,7 +509,7 @@
      * Gets the value of the packagedForDownload property.
      * 
      */
-    public synchronized boolean isPackagedForDownload() {
+    public boolean isPackagedForDownload() {
         return packagedForDownload;
     }
 
@@ -517,7 +517,7 @@
      * Sets the value of the packagedForDownload property.
      * 
      */
-    public synchronized void setPackagedForDownload(boolean value) {
+    public void setPackagedForDownload(boolean value) {
         this.packagedForDownload = value;
     }
 
@@ -529,7 +529,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getUserForum() {
+    public String getUserForum() {
         return userForum;
     }
 
@@ -541,7 +541,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setUserForum(String value) {
+    public void setUserForum(String value) {
         this.userForum = value;
     }
 
@@ -553,7 +553,7 @@
      *     {@link String }
      *     
      */
-    public synchronized String getDevForum() {
+    public String getDevForum() {
         return devForum;
     }
 
@@ -565,7 +565,7 @@
      *     {@link String }
      *     
      */
-    public synchronized void setDevForum(String value) {
+    public void setDevForum(String value) {
         this.devForum = value;
     }
 
@@ -591,7 +591,7 @@
      * 
      * 
      */
-    public synchronized List<DocumentationRW> getDocumentation() {
+    public List<DocumentationRW> getDocumentation() {
         if (documentation == null) {
             documentation = new CopyOnWriteArrayList<DocumentationRW>();
         }
@@ -606,7 +606,7 @@
      *     {@link PagesRW }
      *     
      */
-    public synchronized PagesRW getPages() {
+    public PagesRW getPages() {
         return pages;
     }
 
@@ -618,7 +618,7 @@
      *     {@link PagesRW }
      *     
      */
-    public synchronized void setPages(PagesRW value) {
+    public void setPages(PagesRW value) {
         this.pages = value;
     }
 
@@ -630,7 +630,7 @@
      *     {@link DownloadsRW }
      *     
      */
-    public synchronized DownloadsRW getDownloads() {
+    public DownloadsRW getDownloads() {
         return downloads;
     }
 
@@ -642,7 +642,7 @@
      *     {@link DownloadsRW }
      *     
      */
-    public synchronized void setDownloads(DownloadsRW value) {
+    public void setDownloads(DownloadsRW value) {
         this.downloads = value;
     }
 
@@ -654,7 +654,7 @@
      *     {@link PollsRW }
      *     
      */
-    public synchronized PollsRW getPolls() {
+    public PollsRW getPolls() {
         return polls;
     }
 
@@ -666,7 +666,7 @@
      *     {@link PollsRW }
      *     
      */
-    public synchronized void setPolls(PollsRW value) {
+    public void setPolls(PollsRW value) {
         this.polls = value;
     }
 
@@ -352,32 +352,32 @@
 
     /**
-     * Gets the value of the commmiterRepo property.
+     * Gets the value of the commiterRepo property.
      * 
      * @return
@@ -352,32 +352,32 @@
 
     /**
-     * Sets the value of the commmiterRepo property.
+     * Sets the value of the commiterRepo property.
      * 
      * @param value

Modified: labs/jbosslabs/trunk/portal-extensions/forge-common/src/web/WEB-INF/project.xsd
===================================================================